'''
Utility functions that shore up some of the built in functionality
for tuples with extensions, pushes, and inserts.
'''
from pythonix.internals.tup import (
    count_occurrences,
    extend,
    extend_left,
    extend_right,
    get,
    first,
    index,
    last,
    push,
    push_left,
    push_right,
    insert,
    remove,
    new,
    Side,
)
